@@ -1,19 +1,8 @@
 /*
- * Copyright (C) 2017 by Friedrich W. H. Kossebau <kossebau@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "markdownbrowserextension.h"
 
@@ -32,7 +21,7 @@ MarkdownBrowserExtension::MarkdownBrowserExtension(MarkdownPart* part)
     , m_part(part)
     , m_contextMenuActionCollection(new KActionCollection(this))
 {
-     emit enableAction("copy", m_part->view()->isCopyTextEnabled());
+     Q_EMIT enableAction("copy", m_part->view()->isCopyTextEnabled());
 }
 
 void MarkdownBrowserExtension::copy()
@@ -42,17 +31,17 @@ void MarkdownBrowserExtension::copy()
 
 void MarkdownBrowserExtension::updateCopyAction(bool enabled)
 {
-    emit enableAction("copy", enabled);
+    Q_EMIT enableAction("copy", enabled);
 }
 
 void MarkdownBrowserExtension::requestOpenUrl(const QUrl& url)
 {
-    emit openUrlRequest(url);
+    Q_EMIT openUrlRequest(url);
 }
 
 void MarkdownBrowserExtension::requestOpenUrlNewWindow(const QUrl& url)
 {
-    emit createNewWindow(url);
+    Q_EMIT createNewWindow(url);
 }
 
 void MarkdownBrowserExtension::requestContextMenu(const QPoint& globalPos,
@@ -77,7 +66,7 @@ void MarkdownBrowserExtension::requestContextMenu(const QPoint& globalPos,
 
             QList<QAction*> selectActions;
 
-            auto action = m_part->copySelectionAction();
+            QAction* action = m_part->copySelectionAction();
             selectActions.append(action);
 
             mapAction.insert(QStringLiteral("editactions"), selectActions);
@@ -93,7 +82,7 @@ void MarkdownBrowserExtension::requestContextMenu(const QPoint& globalPos,
             const QString fileName = linkUrl.fileName();
 
             if (!fileName.isEmpty() && !linkUrl.hasFragment() && !linkUrl.hasQuery()) {
-                auto mime = mimeDb.mimeTypeForFile(fileName);
+                const QMimeType mime = mimeDb.mimeTypeForFile(fileName);
                 if (!mime.isDefault()) {
                     mimeType = mime.name();
                 }
@@ -103,22 +92,22 @@ void MarkdownBrowserExtension::requestContextMenu(const QPoint& globalPos,
         QList<QAction*> linkActions;
 
         if (hasSelection) {
-            auto action = m_part->copySelectionAction();
+            QAction* action = m_part->copySelectionAction();
             linkActions.append(action);
         }
 
         if (linkUrl.scheme() == QLatin1String("mailto")) {
-            auto action = m_part->createCopyEmailAddressAction(m_contextMenuActionCollection, linkUrl);
+            QAction* action = m_part->createCopyEmailAddressAction(m_contextMenuActionCollection, linkUrl);
             m_contextMenuActionCollection->addAction(QStringLiteral("copylinklocation"), action);
             linkActions.append(action);
         } else {
             if (!linkText.isEmpty()) {
-                auto action = m_part->createCopyLinkTextAction(m_contextMenuActionCollection, linkText);
+                QAction* action = m_part->createCopyLinkTextAction(m_contextMenuActionCollection, linkText);
                 m_contextMenuActionCollection->addAction(QStringLiteral("copylinktext"), action);
                 linkActions.append(action);
             }
 
-            auto action = m_part->createCopyLinkUrlAction(m_contextMenuActionCollection);
+            QAction* action = m_part->createCopyLinkUrlAction(m_contextMenuActionCollection);
             m_contextMenuActionCollection->addAction(QStringLiteral("copylinkurl"), action);
             linkActions.append(action);
 
@@ -136,7 +125,7 @@ void MarkdownBrowserExtension::requestContextMenu(const QPoint& globalPos,
         KParts::BrowserArguments bargs;
         bargs.setForcesNewWindow(forcesNewWindow);
 
-        emit popupMenu(globalPos, emitUrl, static_cast<mode_t>(-1), args, bargs, flags, mapAction);
+        Q_EMIT popupMenu(globalPos, emitUrl, static_cast<mode_t>(-1), args, bargs, flags, mapAction);
     }
 }
 
