@@ -1,19 +1,8 @@
 /*
- * Copyright (C) 2017 by Friedrich W. H. Kossebau <kossebau@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "markdownpart.h"
 
@@ -57,8 +46,8 @@ MarkdownPart::MarkdownPart(QWidget* parentWidget, QObject* parent, const KAboutD
     setComponentData(aboutData);
 
     // set internal UI
-    auto mainLayout = new QVBoxLayout;
-    mainLayout->setMargin(0);
+    auto* mainLayout = new QVBoxLayout;
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
 
     mainLayout->addWidget(m_widget);
@@ -66,7 +55,7 @@ MarkdownPart::MarkdownPart(QWidget* parentWidget, QObject* parent, const KAboutD
     m_searchToolBar->hide();
     mainLayout->addWidget(m_searchToolBar);
 
-    auto mainWidget = new QWidget(parentWidget);
+    auto* mainWidget = new QWidget(parentWidget);
     mainWidget->setLayout(mainLayout);
     setWidget(mainWidget);
 
@@ -127,7 +116,7 @@ void MarkdownPart::setupActions(Modus modus)
     m_searchPreviousAction->setEnabled(false);
     m_widget->addAction(m_searchPreviousAction);
 
-    auto closeFindBarShortcut = new QShortcut(QKeySequence(Qt::Key_Escape), widget());
+    auto* closeFindBarShortcut = new QShortcut(QKeySequence(Qt::Key_Escape), widget());
     closeFindBarShortcut->setContext(Qt::WidgetWithChildrenShortcut);
     connect(closeFindBarShortcut, &QShortcut::activated, m_searchToolBar, &SearchToolBar::hide);
 }
@@ -159,7 +148,7 @@ bool MarkdownPart::openFile()
 
 bool MarkdownPart::doOpenStream(const QString& mimeType)
 {
-    auto mime = QMimeDatabase().mimeTypeForName(mimeType);
+    const QMimeType mime = QMimeDatabase().mimeTypeForName(mimeType);
     if (!mime.inherits(QStringLiteral("text/markdown"))) {
         return false;
     }
@@ -204,7 +193,7 @@ bool MarkdownPart::doCloseStream()
 bool MarkdownPart::closeUrl()
 {
     // protect against repeated call if already closed
-    const auto currentUrl = url();
+    const QUrl currentUrl = url();
     if (currentUrl.isValid()) {
         m_previousScrollPosition = m_widget->scrollPosition();
         m_previousUrl = currentUrl;
@@ -260,7 +249,7 @@ void MarkdownPart::requestContextMenu(const QPoint& globalPos,
             }
         }
     } else {
-        auto action = menu.addAction(i18n("Open Link"));
+        QAction* action = menu.addAction(i18n("Open Link"));
         connect(action, &QAction::triggered, this, [&] {
             handleOpenUrlRequest(linkUrl);
         });
@@ -277,7 +266,7 @@ void MarkdownPart::requestContextMenu(const QPoint& globalPos,
         }
     }
 #ifdef DEBUG_WEB
-    auto action = menu.addAction(QStringLiteral("Inspect Element"));
+    QAction* action = menu.addAction(QStringLiteral("Inspect Element"));
     connect(action, &QAction::triggered, m_widget, &KMarkdownView::inspectElement);
 #endif
 
@@ -304,14 +293,14 @@ void MarkdownPart::showHoveredLink(const QString& link)
         } else {
             message = linkUrl.toString();
 
-            if (QString::compare(scheme, QLatin1String("mailto"), Qt::CaseInsensitive) == 0) {
+            if (scheme != QLatin1String("mailto")) {
                 fileItem = KFileItem(linkUrl, QString(), KFileItem::Unknown);
             }
         }
     }
 
-    emit m_browserExtension->mouseOverInfo(fileItem);
-    emit setStatusBarText(message);
+    Q_EMIT m_browserExtension->mouseOverInfo(fileItem);
+    Q_EMIT setStatusBarText(message);
 }
 
 QAction* MarkdownPart::copySelectionAction() const
@@ -321,10 +310,10 @@ QAction* MarkdownPart::copySelectionAction() const
 
 QAction* MarkdownPart::createCopyEmailAddressAction(QObject* parent, const QUrl& mailtoUrl)
 {
-    auto action = new QAction(parent);
+    auto* action = new QAction(parent);
     action->setText(i18n("&Copy Email Address"));
     connect(action, &QAction::triggered, parent, [&] {
-        QMimeData* data = new QMimeData;
+        auto* data = new QMimeData;
         data->setText(mailtoUrl.path());
         QApplication::clipboard()->setMimeData(data, QClipboard::Clipboard);
     });
@@ -334,11 +323,11 @@ QAction* MarkdownPart::createCopyEmailAddressAction(QObject* parent, const QUrl&
 
 QAction* MarkdownPart::createCopyLinkTextAction(QObject* parent, const QString& text)
 {
-    auto action = new QAction(parent);
+    auto* action = new QAction(parent);
     action->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     action->setText(i18n("Copy Link &Text"));
     connect(action, &QAction::triggered, parent, [&] {
-        QMimeData* data = new QMimeData;
+        auto* data = new QMimeData;
         data->setText(text);
         QApplication::clipboard()->setMimeData(data, QClipboard::Clipboard);
     });
@@ -348,7 +337,7 @@ QAction* MarkdownPart::createCopyLinkTextAction(QObject* parent, const QString&
 
 QAction* MarkdownPart::createCopyLinkUrlAction(QObject* parent)
 {
-    auto action = new QAction(parent);
+    auto* action = new QAction(parent);
     action->setText(i18n("Copy Link &URL"));
     connect(action, &QAction::triggered, this, &MarkdownPart::copyLinkUrl);
 
@@ -357,7 +346,7 @@ QAction* MarkdownPart::createCopyLinkUrlAction(QObject* parent)
 
 QAction* MarkdownPart::createSaveLinkAsAction(QObject* parent)
 {
-    auto action = new QAction(parent);
+    auto* action = new QAction(parent);
     action->setText(i18n("&Save Link As..."));
     connect(action, &QAction::triggered, this, &MarkdownPart::saveLinkAs);
 
